@@ -1,5 +1,5 @@
 package Image::PNG::Const;
-our $VERSION = '0.38_01';
+our $VERSION = '0.44_01';
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -71,6 +71,7 @@ PNG_INFO_iCCP
 PNG_INFO_sPLT
 PNG_INFO_sCAL
 PNG_INFO_IDAT
+PNG_INFO_eXIf
 PNG_INFO_acTL
 PNG_INFO_fcTL
 PNG_TRANSFORM_IDENTITY
@@ -114,7 +115,6 @@ PNG_BACKGROUND_GAMMA_UNKNOWN
 PNG_BACKGROUND_GAMMA_SCREEN
 PNG_BACKGROUND_GAMMA_FILE
 PNG_BACKGROUND_GAMMA_UNIQUE
-PNG_READ_16_TO_8
 PNG_GAMMA_THRESHOLD
 PNG_CRC_DEFAULT
 PNG_CRC_ERROR_QUIT
@@ -128,6 +128,7 @@ PNG_FILTER_SUB
 PNG_FILTER_UP
 PNG_FILTER_AVG
 PNG_FILTER_PAETH
+PNG_FAST_FILTERS
 PNG_ALL_FILTERS
 PNG_FILTER_VALUE_NONE
 PNG_FILTER_VALUE_SUB
@@ -147,10 +148,10 @@ PNG_FREE_ROWS
 PNG_FREE_PCAL
 PNG_FREE_SCAL
 PNG_FREE_UNKN
-PNG_FREE_LIST
 PNG_FREE_PLTE
 PNG_FREE_TRNS
 PNG_FREE_TEXT
+PNG_FREE_EXIF
 PNG_FREE_ALL
 PNG_FREE_MUL
 PNG_HANDLE_CHUNK_AS_DEFAULT
@@ -167,7 +168,43 @@ PNG_IO_CHUNK_CRC
 PNG_IO_MASK_OP
 PNG_IO_MASK_LOC
 PNG_INTERLACE_ADAM7_PASSES
+PNG_IMAGE_VERSION
+PNG_IMAGE_WARNING
+PNG_IMAGE_ERROR
+PNG_FORMAT_FLAG_ALPHA
+PNG_FORMAT_FLAG_COLOR
+PNG_FORMAT_FLAG_LINEAR
+PNG_FORMAT_FLAG_COLORMAP
+PNG_FORMAT_FLAG_BGR
+PNG_FORMAT_FLAG_AFIRST
+PNG_FORMAT_FLAG_ASSOCIATED_ALPHA
+PNG_FORMAT_GRAY
+PNG_FORMAT_GA
+PNG_FORMAT_AG
+PNG_FORMAT_RGB
+PNG_FORMAT_BGR
+PNG_FORMAT_RGBA
+PNG_FORMAT_ARGB
+PNG_FORMAT_BGRA
+PNG_FORMAT_ABGR
+PNG_FORMAT_LINEAR_Y
+PNG_FORMAT_LINEAR_Y_ALPHA
+PNG_FORMAT_LINEAR_RGB
+PNG_FORMAT_RGB_COLORMAP
+PNG_FORMAT_BGR_COLORMAP
+PNG_FORMAT_RGBA_COLORMAP
+PNG_FORMAT_ARGB_COLORMAP
+PNG_FORMAT_BGRA_COLORMAP
+PNG_FORMAT_ABGR_COLORMAP
+PNG_IMAGE_FLAG_COLORSPACE_NOT_sRGB
+PNG_IMAGE_FLAG_FAST
+PNG_IMAGE_FLAG_16BIT_sRGB
 PNG_ARM_NEON
+PNG_MAXIMUM_INFLATE_WINDOW
+PNG_SKIP_sRGB_CHECK_PROFILE
+PNG_MIPS_MSA
+PNG_IGNORE_ADLER32
+PNG_POWERPC_VSX
 PNG_OPTION_NEXT
 PNG_OPTION_UNSET
 PNG_OPTION_INVALID
@@ -253,8 +290,9 @@ use constant {
     PNG_INFO_sPLT => 0x2000,
     PNG_INFO_sCAL => 0x4000,
     PNG_INFO_IDAT => 0x8000,
-    PNG_INFO_acTL => 0x10000,
-    PNG_INFO_fcTL => 0x20000,
+    PNG_INFO_eXIf => 0x10000,
+    PNG_INFO_acTL => 0x20000,
+    PNG_INFO_fcTL => 0x40000,
     PNG_TRANSFORM_IDENTITY => 0x0000,
     PNG_TRANSFORM_STRIP_16 => 0x0001,
     PNG_TRANSFORM_STRIP_ALPHA => 0x0002,
@@ -296,7 +334,6 @@ use constant {
     PNG_BACKGROUND_GAMMA_SCREEN => 1,
     PNG_BACKGROUND_GAMMA_FILE => 2,
     PNG_BACKGROUND_GAMMA_UNIQUE => 3,
-    PNG_READ_16_TO_8 => SUPPORTED,
     PNG_GAMMA_THRESHOLD => (PNG_GAMMA_THRESHOLD_FIXED*.00001),
     PNG_CRC_DEFAULT => 0,
     PNG_CRC_ERROR_QUIT => 1,
@@ -310,7 +347,8 @@ use constant {
     PNG_FILTER_UP => 0x20,
     PNG_FILTER_AVG => 0x40,
     PNG_FILTER_PAETH => 0x80,
-    PNG_ALL_FILTERS => (0x08 | 0x10 | 0x20 | 0x40 | 0x80),
+    PNG_FAST_FILTERS => (0x08 | 0x10 | 0x20),
+    PNG_ALL_FILTERS => ((0x08 | 0x10 | 0x20) | 0x40 | 0x80),
     PNG_FILTER_VALUE_NONE => 0,
     PNG_FILTER_VALUE_SUB => 1,
     PNG_FILTER_VALUE_UP => 2,
@@ -329,11 +367,11 @@ use constant {
     PNG_FREE_PCAL => 0x0080,
     PNG_FREE_SCAL => 0x0100,
     PNG_FREE_UNKN => 0x0200,
-    PNG_FREE_LIST => 0x0400,
     PNG_FREE_PLTE => 0x1000,
     PNG_FREE_TRNS => 0x2000,
     PNG_FREE_TEXT => 0x4000,
-    PNG_FREE_ALL => 0x7fff,
+    PNG_FREE_EXIF => 0x8000,
+    PNG_FREE_ALL => 0xffff,
     PNG_FREE_MUL => 0x4220,
     PNG_HANDLE_CHUNK_AS_DEFAULT => 0,
     PNG_HANDLE_CHUNK_NEVER => 1,
@@ -349,8 +387,44 @@ use constant {
     PNG_IO_MASK_OP => 0x000f,
     PNG_IO_MASK_LOC => 0x00f0,
     PNG_INTERLACE_ADAM7_PASSES => 7,
+    PNG_IMAGE_VERSION => 1,
+    PNG_IMAGE_WARNING => 1,
+    PNG_IMAGE_ERROR => 2,
+    PNG_FORMAT_FLAG_ALPHA => 0x01,
+    PNG_FORMAT_FLAG_COLOR => 0x02,
+    PNG_FORMAT_FLAG_LINEAR => 0x04,
+    PNG_FORMAT_FLAG_COLORMAP => 0x08,
+    PNG_FORMAT_FLAG_BGR => 0x10,
+    PNG_FORMAT_FLAG_AFIRST => 0x20,
+    PNG_FORMAT_FLAG_ASSOCIATED_ALPHA => 0x40,
+    PNG_FORMAT_GRAY => 0,
+    PNG_FORMAT_GA => 0x01,
+    PNG_FORMAT_AG => (0x01|0x20),
+    PNG_FORMAT_RGB => 0x02,
+    PNG_FORMAT_BGR => (0x02|0x10),
+    PNG_FORMAT_RGBA => (0x02|0x01),
+    PNG_FORMAT_ARGB => ((0x02|0x01)|0x20),
+    PNG_FORMAT_BGRA => ((0x02|0x10)|0x01),
+    PNG_FORMAT_ABGR => (((0x02|0x10)|0x01)|0x20),
+    PNG_FORMAT_LINEAR_Y => 0x04,
+    PNG_FORMAT_LINEAR_Y_ALPHA => (0x04|0x01),
+    PNG_FORMAT_LINEAR_RGB => (0x04|0x02),
+    PNG_FORMAT_RGB_COLORMAP => (0x02|0x08),
+    PNG_FORMAT_BGR_COLORMAP => ((0x02|0x10)|0x08),
+    PNG_FORMAT_RGBA_COLORMAP => ((0x02|0x01)|0x08),
+    PNG_FORMAT_ARGB_COLORMAP => (((0x02|0x01)|0x20)|0x08),
+    PNG_FORMAT_BGRA_COLORMAP => (((0x02|0x10)|0x01)|0x08),
+    PNG_FORMAT_ABGR_COLORMAP => ((((0x02|0x10)|0x01)|0x20)|0x08),
+    PNG_IMAGE_FLAG_COLORSPACE_NOT_sRGB => 0x01,
+    PNG_IMAGE_FLAG_FAST => 0x02,
+    PNG_IMAGE_FLAG_16BIT_sRGB => 0x04,
     PNG_ARM_NEON => 0,
-    PNG_OPTION_NEXT => 2,
+    PNG_MAXIMUM_INFLATE_WINDOW => 2,
+    PNG_SKIP_sRGB_CHECK_PROFILE => 4,
+    PNG_MIPS_MSA => 6,
+    PNG_IGNORE_ADLER32 => 8,
+    PNG_POWERPC_VSX => 10,
+    PNG_OPTION_NEXT => 12,
     PNG_OPTION_UNSET => 0,
     PNG_OPTION_INVALID => 1,
     PNG_OPTION_OFF => 2,
@@ -647,13 +721,17 @@ PNG_INFO_sCAL has value 0x4000.
 
 PNG_INFO_IDAT has value 0x8000.
 
+=item PNG_INFO_eXIf
+
+PNG_INFO_eXIf has value 0x10000.
+
 =item PNG_INFO_acTL
 
-PNG_INFO_acTL has value 0x10000.
+PNG_INFO_acTL has value 0x20000.
 
 =item PNG_INFO_fcTL
 
-PNG_INFO_fcTL has value 0x20000.
+PNG_INFO_fcTL has value 0x40000.
 
 =item PNG_TRANSFORM_IDENTITY
 
@@ -819,10 +897,6 @@ PNG_BACKGROUND_GAMMA_FILE has value 2.
 
 PNG_BACKGROUND_GAMMA_UNIQUE has value 3.
 
-=item PNG_READ_16_TO_8
-
-PNG_READ_16_TO_8 has value SUPPORTED.
-
 =item PNG_GAMMA_THRESHOLD
 
 PNG_GAMMA_THRESHOLD has value (PNG_GAMMA_THRESHOLD_FIXED*.00001).
@@ -875,9 +949,13 @@ PNG_FILTER_AVG has value 0x40.
 
 PNG_FILTER_PAETH has value 0x80.
 
+=item PNG_FAST_FILTERS
+
+PNG_FAST_FILTERS has value (0x08 | 0x10 | 0x20).
+
 =item PNG_ALL_FILTERS
 
-PNG_ALL_FILTERS has value (0x08 | 0x10 | 0x20 | 0x40 | 0x80).
+PNG_ALL_FILTERS has value ((0x08 | 0x10 | 0x20) | 0x40 | 0x80).
 
 =item PNG_FILTER_VALUE_NONE
 
@@ -951,10 +1029,6 @@ PNG_FREE_SCAL has value 0x0100.
 
 PNG_FREE_UNKN has value 0x0200.
 
-=item PNG_FREE_LIST
-
-PNG_FREE_LIST has value 0x0400.
-
 =item PNG_FREE_PLTE
 
 PNG_FREE_PLTE has value 0x1000.
@@ -967,9 +1041,13 @@ PNG_FREE_TRNS has value 0x2000.
 
 PNG_FREE_TEXT has value 0x4000.
 
+=item PNG_FREE_EXIF
+
+PNG_FREE_EXIF has value 0x8000.
+
 =item PNG_FREE_ALL
 
-PNG_FREE_ALL has value 0x7fff.
+PNG_FREE_ALL has value 0xffff.
 
 =item PNG_FREE_MUL
 
@@ -1031,13 +1109,157 @@ PNG_IO_MASK_LOC has value 0x00f0.
 
 PNG_INTERLACE_ADAM7_PASSES has value 7.
 
+=item PNG_IMAGE_VERSION
+
+PNG_IMAGE_VERSION has value 1.
+
+=item PNG_IMAGE_WARNING
+
+PNG_IMAGE_WARNING has value 1.
+
+=item PNG_IMAGE_ERROR
+
+PNG_IMAGE_ERROR has value 2.
+
+=item PNG_FORMAT_FLAG_ALPHA
+
+PNG_FORMAT_FLAG_ALPHA has value 0x01.
+
+=item PNG_FORMAT_FLAG_COLOR
+
+PNG_FORMAT_FLAG_COLOR has value 0x02.
+
+=item PNG_FORMAT_FLAG_LINEAR
+
+PNG_FORMAT_FLAG_LINEAR has value 0x04.
+
+=item PNG_FORMAT_FLAG_COLORMAP
+
+PNG_FORMAT_FLAG_COLORMAP has value 0x08.
+
+=item PNG_FORMAT_FLAG_BGR
+
+PNG_FORMAT_FLAG_BGR has value 0x10.
+
+=item PNG_FORMAT_FLAG_AFIRST
+
+PNG_FORMAT_FLAG_AFIRST has value 0x20.
+
+=item PNG_FORMAT_FLAG_ASSOCIATED_ALPHA
+
+PNG_FORMAT_FLAG_ASSOCIATED_ALPHA has value 0x40.
+
+=item PNG_FORMAT_GRAY
+
+PNG_FORMAT_GRAY has value 0.
+
+=item PNG_FORMAT_GA
+
+PNG_FORMAT_GA has value 0x01.
+
+=item PNG_FORMAT_AG
+
+PNG_FORMAT_AG has value (0x01|0x20).
+
+=item PNG_FORMAT_RGB
+
+PNG_FORMAT_RGB has value 0x02.
+
+=item PNG_FORMAT_BGR
+
+PNG_FORMAT_BGR has value (0x02|0x10).
+
+=item PNG_FORMAT_RGBA
+
+PNG_FORMAT_RGBA has value (0x02|0x01).
+
+=item PNG_FORMAT_ARGB
+
+PNG_FORMAT_ARGB has value ((0x02|0x01)|0x20).
+
+=item PNG_FORMAT_BGRA
+
+PNG_FORMAT_BGRA has value ((0x02|0x10)|0x01).
+
+=item PNG_FORMAT_ABGR
+
+PNG_FORMAT_ABGR has value (((0x02|0x10)|0x01)|0x20).
+
+=item PNG_FORMAT_LINEAR_Y
+
+PNG_FORMAT_LINEAR_Y has value 0x04.
+
+=item PNG_FORMAT_LINEAR_Y_ALPHA
+
+PNG_FORMAT_LINEAR_Y_ALPHA has value (0x04|0x01).
+
+=item PNG_FORMAT_LINEAR_RGB
+
+PNG_FORMAT_LINEAR_RGB has value (0x04|0x02).
+
+=item PNG_FORMAT_RGB_COLORMAP
+
+PNG_FORMAT_RGB_COLORMAP has value (0x02|0x08).
+
+=item PNG_FORMAT_BGR_COLORMAP
+
+PNG_FORMAT_BGR_COLORMAP has value ((0x02|0x10)|0x08).
+
+=item PNG_FORMAT_RGBA_COLORMAP
+
+PNG_FORMAT_RGBA_COLORMAP has value ((0x02|0x01)|0x08).
+
+=item PNG_FORMAT_ARGB_COLORMAP
+
+PNG_FORMAT_ARGB_COLORMAP has value (((0x02|0x01)|0x20)|0x08).
+
+=item PNG_FORMAT_BGRA_COLORMAP
+
+PNG_FORMAT_BGRA_COLORMAP has value (((0x02|0x10)|0x01)|0x08).
+
+=item PNG_FORMAT_ABGR_COLORMAP
+
+PNG_FORMAT_ABGR_COLORMAP has value ((((0x02|0x10)|0x01)|0x20)|0x08).
+
+=item PNG_IMAGE_FLAG_COLORSPACE_NOT_sRGB
+
+PNG_IMAGE_FLAG_COLORSPACE_NOT_sRGB has value 0x01.
+
+=item PNG_IMAGE_FLAG_FAST
+
+PNG_IMAGE_FLAG_FAST has value 0x02.
+
+=item PNG_IMAGE_FLAG_16BIT_sRGB
+
+PNG_IMAGE_FLAG_16BIT_sRGB has value 0x04.
+
 =item PNG_ARM_NEON
 
 PNG_ARM_NEON has value 0.
 
+=item PNG_MAXIMUM_INFLATE_WINDOW
+
+PNG_MAXIMUM_INFLATE_WINDOW has value 2.
+
+=item PNG_SKIP_sRGB_CHECK_PROFILE
+
+PNG_SKIP_sRGB_CHECK_PROFILE has value 4.
+
+=item PNG_MIPS_MSA
+
+PNG_MIPS_MSA has value 6.
+
+=item PNG_IGNORE_ADLER32
+
+PNG_IGNORE_ADLER32 has value 8.
+
+=item PNG_POWERPC_VSX
+
+PNG_POWERPC_VSX has value 10.
+
 =item PNG_OPTION_NEXT
 
-PNG_OPTION_NEXT has value 2.
+PNG_OPTION_NEXT has value 12.
 
 =item PNG_OPTION_UNSET
 
@@ -1069,35 +1291,24 @@ all the symbols in this module:
 
 This Perl module was generated from C<png.h>.
 
+
+
 =head1 AUTHOR
 
 Ben Bullock, <bkb@cpan.org>
 
 =head1 COPYRIGHT & LICENCE
 
-The Image::PNG::Libpng package and associated files are copyright (C)
-2014 Ben Bullock.
+This package and associated files are copyright (C) 
+-2017
+Ben Bullock.
 
-You can use, copy, modify and redistribute Image::PNG::Libpng and
-associated files under the Perl Artistic Licence or the GNU General
-Public Licence.
-
-=head1 SUPPORT
-
-=head2 Mailing list
-
-There is a mailing list at
-L<http://groups.google.com/group/perlimagepng>. It is not necessary to
-be a member of the list to post messages to the list or participate in
-discussions.
-
-=head2 Reporting a bug
-
-There is a bug tracker at L<https://github.com/benkasminbullock/image-png-libpng/issues>.
+You can use, copy, modify and redistribute this package and associated
+files under the Perl Artistic Licence or the GNU General Public
+Licence.
 
 
 
-=cut
 
 # Local variables:
 # mode: perl
